@@ -154,4 +154,7 @@ def delimitedby_regexp(char, escape):
 def allbut_regexp(patterns, escape):
     if not isinstance(patterns, list):
         patterns = [patterns]
-    return re.compile("({1}({0})|(?!({0})).)+".format("|".join([re.escape(s) for s in patterns]), re.escape(escape)), re.DOTALL)
\ No newline at end of file
+    return re.compile("({1}({0})|(?!({0})).)+".format("|".join([re.escape(s) for s in patterns]), re.escape(escape)), re.DOTALL)
+
+def delimitedby_regexp_escapes(char, escapes):
+    return re.compile(u("{0}({1}|(?!{0}).)*{0}").format(re.escape(char), escapes))
